@@ -78,31 +78,31 @@ var tbSyncEasNewAccount = {
         if (this.elementServertype) {
             switch (this.elementServertype.value) {
                 case "select":            
-                    document.getElementById('tbsync.newaccount.user.box').style.visibility = "hidden";
-                    document.getElementById('tbsync.newaccount.url.box').style.visibility = "hidden";
-                    document.getElementById('tbsync.newaccount.password.box').style.visibility = "hidden";
+                    document.getElementById('tbsync.newaccount.user.box').hidden = true;
+                    document.getElementById('tbsync.newaccount.url.box').hidden = true;
+                    document.getElementById('tbsync.newaccount.password.box').hidden = true;
                     document.documentElement.getButton("finish").label = TbSync.getString("newaccount.add_custom","eas");
                     break;
 
                 case "auto":            
-                    document.getElementById('tbsync.newaccount.user.box').style.visibility = "visible";
-                    document.getElementById('tbsync.newaccount.url.box').style.visibility = "hidden";
-                    document.getElementById('tbsync.newaccount.password.box').style.visibility = "visible";
+                    document.getElementById('tbsync.newaccount.user.box').hidden = false;
+                    document.getElementById('tbsync.newaccount.url.box').hidden = true;
+                    document.getElementById('tbsync.newaccount.password.box').hidden = false;
                     document.documentElement.getButton("finish").label = TbSync.getString("newaccount.add_auto","eas");
                     break;
                 
                 case "office365":            
-                    document.getElementById('tbsync.newaccount.user.box').style.visibility = "visible";
-                    document.getElementById('tbsync.newaccount.url.box').style.visibility = "hidden";
-                    document.getElementById('tbsync.newaccount.password.box').style.visibility = "hidden";
+                    document.getElementById('tbsync.newaccount.user.box').hidden = false;
+                    document.getElementById('tbsync.newaccount.url.box').hidden = true;
+                    document.getElementById('tbsync.newaccount.password.box').hidden = true;
                     document.documentElement.getButton("finish").label = TbSync.getString("newaccount.add_custom","eas");
                     break;
 
                 case "custom":
                 default:
-                    document.getElementById('tbsync.newaccount.user.box').style.visibility = "visible";
-                    document.getElementById('tbsync.newaccount.url.box').style.visibility = "visible";
-                    document.getElementById('tbsync.newaccount.password.box').style.visibility = "visible";
+                    document.getElementById('tbsync.newaccount.user.box').hidden = false;
+                    document.getElementById('tbsync.newaccount.url.box').hidden = false;
+                    document.getElementById('tbsync.newaccount.password.box').hidden = false;
                     document.documentElement.getButton("finish").label = TbSync.getString("newaccount.add_custom","eas");
                     break;
             }
